@@ -1,4 +1,4 @@
-autoevenn <-function(FolderPath="", annot=TRUE, ud=TRUE, VennBar=FALSE, Solid=TRUE, Profils=TRUE, prop=FALSE, display=FALSE, Ptest=FALSE)
+autoevenn <-function(FolderPath="", annot=TRUE, ud=TRUE, VennBar=FALSE, Solid=TRUE, Profils=TRUE, prop=FALSE, display=FALSE, Ptest=FALSE, tUD=NULL, tUDp=NULL, tnoUD=NULL, ColorTxt="", Gtype="png")
 {
 	if(FolderPath=="")
 	{
@@ -20,6 +20,6 @@ autoevenn <-function(FolderPath="", annot=TRUE, ud=TRUE, VennBar=FALSE, Solid=TR
 	for(V in 1:length(Venns))
 	{
 		write(paste(V, " / ", length(Venns), ": ", basename(Venns[V]), sep=""), file="")
-		evenn(annot=annot, ud=ud, VennBar=VennBar, pathRes=FolderDest, pathLists=Venns[V], display=display, Solid=Solid, Profils=Profils, prop=prop, Ptest=Ptest)
+		evenn(annot=annot, ud=ud, VennBar=VennBar, pathRes=FolderDest, pathLists=Venns[V], display=display, Solid=Solid, Profils=Profils, prop=prop, Ptest=Ptest, , tUD=tUD, tUDp=tUDp, tnoUD=tnoUD, ColorTxt=ColorTxt, Gtype=Gtype)
 	}
 }
